@@ -1,13 +1,14 @@
 mod armor_and_skills;
 mod build_search;
 mod locale;
+mod profile;
 mod style_iced;
 mod ui_iced;
-mod profile;
+mod update;
 
 use std::sync::Mutex;
 
-use iced::{Sandbox, Settings};
+use iced::{Application, Settings};
 use locale::Locale;
 use once_cell::sync::Lazy;
 
@@ -16,6 +17,9 @@ const FONT: &[u8] = include_bytes!("fonts/FiraSans-Regular.ttf");
 // If you have another solution don't hesitate to tell me.
 static LOCALE: Lazy<Mutex<Option<Locale>>> = Lazy::new(Default::default);
 
+const ARMORS_PATH: &str = "armors";
+const LOCALE_DIR_PATH: &str = "locale";
+
 pub fn main() -> iced::Result {
     ui_iced::MainApp::run(Settings {
         default_font: Some(FONT),
